<?php

/**
 * Plugin Name: YANSIR B2B
 * Description: 修改文案、移除价格，让WC插件更好地适应外贸B2B。
 * Plugin URI: https://xunpanziyou.com/
 * Author: Yansir
 * Version: 1.0.0
 * Author URI: https://xunpanziyou.com/author/yansir
 * Text Domain: yansir-b2b
 */

class woo_for_b2b_Plugin{
	public function __construct() {

		// Hook into the admin menu
		add_action( 'admin_menu', array( $this, 'create_plugin_settings_page' ) );
		add_filter( 'acf/settings/path', array( $this, 'update_acf_settings_path' ) );
		add_filter( 'acf/settings/dir', array( $this, 'update_acf_settings_dir' ) );

		include_once( plugin_dir_path( __FILE__ ) . 'vendor/acf/acf.php' );
		include_once( 'php/easymode/init.php' );
		include_once( 'php/functions.php' );

		//是否开启仪表盘建站流程
		if (get_field('custom_dashboard', 'option')) {
			include_once( 'php/custom-dashboard.php' );
		}

		$this->setup_options();

		add_action( 'admin_init', array( $this, 'add_acf_variables' ) );
	}

	public function update_acf_settings_path( $path ) {
		$path = plugin_dir_path( __FILE__ ) . 'vendor/acf/';
		return $path;
	}

	public function update_acf_settings_dir( $dir ) {
		$dir = plugin_dir_url( __FILE__ ) . 'vendor/acf/';
		return $dir;
	}

	public function add_acf_variables() {
		acf_form_head();
	}

	public static function get_kits( $prefix = true ) {
		$posts = \get_posts(
			array(
				'post_type'      => Elementor\TemplateLibrary\Source_Local::CPT,
				'post_status'    => array( 'publish' ),
				'posts_per_page' => -1,
				'orderby'        => 'title',
				'order'          => 'DESC',
				'meta_query'     => array( // @codingStandardsIgnoreLine
					array(
						'key'   => Elementor\Core\Base\Document::TYPE_META_KEY,
						'value' => 'kit',
					),
				),
			)
		);
		$kits = array();

		foreach ( $posts as $post ) {
			$global_kit = (int) get_option( 'elementor_active_kit' );

			$title = $post->post_title;

			if ( $global_kit && $post->ID === $global_kit && $prefix ) {
				/* translators: Global Style Kit post title. */
				$title = sprintf( __( 'Global: %s', 'ang' ), $title );
			}

			$kits[ $post->ID ] = $title;
		}

		return $kits;
	}

//ACF START----------------------------------------------------------------

	public function setup_options() {

		if( function_exists('acf_add_local_field_group') ):

		acf_add_local_field_group(array(
			'key' => 'group_5f844451dba40',
			'title' => 'Woo for B2B Fields Group',
			'fields' => array(
				array(
					'key' => 'field_5f84446cb0c2c',
					'label' => '禁用购物系统',
					'name' => 'hide_cart',
					'type' => 'true_false',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'message' => '是否禁用WooCommerce自带的购物系统？',
					'default_value' => 0,
					'ui' => 0,
					'ui_on_text' => '',
					'ui_off_text' => '',
				),
				array(
					'key' => 'field_5f8446bfd2539',
					'label' => '隐藏“字段”菜单',
					'name' => 'disable_acf',
					'type' => 'true_false',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'message' => '是否隐藏ACF的字段菜单？',
					'default_value' => 0,
					'ui' => 0,
					'ui_on_text' => '',
					'ui_off_text' => '',
				),
				array(
					'key' => 'field_5f84991a4c606',
					'label' => '优化Elementor',
					'name' => 'elementor_optimize',
					'type' => 'true_false',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'message' => '是否让Elementor的和B2B生意更贴切？',
					'default_value' => 0,
					'ui' => 0,
					'ui_on_text' => '',
					'ui_off_text' => '',
				),
				array(
					'key' => 'field_5f85680ad8a5a',
					'label' => '启用新手模式',
					'name' => 'enable_minimize',
					'type' => 'true_false',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'message' => '把WordPress后台和B2B不相关的功能去掉',
					'default_value' => 0,
					'ui' => 0,
					'ui_on_text' => '',
					'ui_off_text' => '',
				),
				// array(
				// 	'key' => 'field_5f85680ad8a5b',
				// 	'label' => '启用建站流程一览',
				// 	'name' => 'custom_dashboard',
				// 	'type' => 'true_false',
				// 	'instructions' => '',
				// 	'required' => 0,
				// 	'conditional_logic' => 0,
				// 	'wrapper' => array(
				// 		'width' => '',
				// 		'class' => '',
				// 		'id' => '',
				// 	),
				// 	'message' => '是否在仪表盘展示建站流程？',
				// 	'default_value' => 0,
				// 	'ui' => 0,
				// 	'ui_on_text' => '',
				// 	'ui_off_text' => '',
				// ),
				// array(
				// 	'key' => 'field_5f846e6b6434a',
				// 	'label' => '启用首页透明页眉',
				// 	'name' => 'overlay_header',
				// 	'type' => 'true_false',
				// 	'instructions' => '',
				// 	'required' => 0,
				// 	'conditional_logic' => 0,
				// 	'wrapper' => array(
				// 		'width' => '',
				// 		'class' => '',
				// 		'id' => '',
				// 	),
				// 	'message' => '是否在首页显示透明页眉？（当前仅支持Elementor）',
				// 	'default_value' => 0,
				// 	'ui' => 0,
				// 	'ui_on_text' => '',
				// 	'ui_off_text' => '',
				// ),
				array(
					'key' => 'field_5f8460a9fc48d',
					'label' => '飞行模式',
					'name' => 'airplane_mode',
					'type' => 'true_false',
					'instructions' => '',
					'required' => 0,
					'conditional_logic' => 0,
					'wrapper' => array(
						'width' => '',
						'class' => '',
						'id' => '',
					),
					'message' => '是否开启飞行模式强制断网，加快网站速度？',
					'default_value' => 0,
					'ui' => 0,
					'ui_on_text' => '',
					'ui_off_text' => '',
				),
				// array(
				// 	'key' => 'field_5f8450c2fc28s',
				// 	'label' => 'Style Kit',
				// 	'name' => 'elementor_active_kit',
				// 	'type' => 'select',
				// 	'choices' => woo_for_b2b_Plugin::get_kits( false ),
				// 	'default_value' => get_option( 'elementor_active_kit' )
				// ),
			),
			'location' => array(
				array(
					array(
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'post',
					),
					array(
						'param' => 'post_type',
						'operator' => '!=',
						'value' => 'post',
					),
				),
			),
			'menu_order' => 0,
			'position' => 'normal',
			'style' => 'default',
			'label_placement' => 'left',
			'instruction_placement' => 'field',
			'hide_on_screen' => '',
			'active' => true,
			'description' => '',
		));

		endif;

	}

//ACF END----------------------------------------------------------------

	public function create_plugin_settings_page() {
		// Add the menu item and page
		$page_title = 'Woo for B2B';
		$menu_title = 'B2B';
		$capability = 'manage_options';
		$slug = 'woo_for_b2b';
		$callback = array( $this, 'plugin_settings_page_content' );
		$position = 100;
		//add_submenu_page( 'woocommerce', $page_title, $menu_title, $capability, $slug, $callback );
		add_menu_page( $page_title, $menu_title, $capability, $slug, $callback );
	}

	public function plugin_settings_page_content() {
		do_action('acf/input/admin_head'); // Add ACF admin head hooks
		do_action('acf/input/admin_enqueue_scripts'); // Add ACF scripts

		$options = array(
			'id' => 'acf-form',
			'post_id' => 'options',
			'new_post' => false,
			'field_groups' => array( 'group_5f844451dba40' ),
			'return' => admin_url('admin.php?page=woo_for_b2b'),
			'html_before_fields' => '<h1 class="b2b-title">WooCommerce B<span style="color: #007cba;">2</span>B设置</h1>',
			'html_after_fields' => '<style>.acf-form-fields{display: flex; flex-wrap: wrap;} .b2b-title{flex-basis: 100%; margin-bottom: 30px;} .acf-form-submit{margin-top: 10px;} .acf-fields>.acf-field{flex-basis: 33.3%}</style>',
			'form' => true,
			'form_attributes' => array(
				'style' => 'margin: 50px;',
			),
			'submit_value' => '保存更改',
		);
		acf_form( $options );
	}
}

//更新整站样式
/*add_action( 'acf/submit_form', function ( $form, $post_id ) {
	if ( $post_id != 'options' ) return;

	$kit = $_POST['acf']['field_5f8450c2fc28s'];

	if ( empty($kit) ) return;

	$ang_options = update_option( 'ang_options', array() );
	$ang_options['global_kit'] = $kit;

	update_option( 'ang_options', $ang_options );
	update_option( 'elementor_active_kit', $kit );
}, 10, 2 );*/

//判断Elementor Pro是否开启
add_action( 'plugins_loaded', function () {
	$active_plugins = get_option('active_plugins');

	$plugins = array(
		'should_active' => array(
			'elementor/elementor.php' => __( 'Elementor', 'yansir-b2b' ),
			//'woocommerce/woocommerce.php' => __( 'Woocommerce', 'yansir-b2b' ),
		),
		'should_not_active' => array(
			// 'elementor-drag-space/spacer-elementor.php' => __( 'Elementor Drag Space', 'yansir-b2b' ),
			'local-optimize/local-optimize.php' => __( 'Local Optimize', 'yansir-b2b' )
		)
	);

	$need_to_active = array();
	$need_to_deactivate = array();

	foreach ( $plugins['should_active'] as $file => $name ) {
		if ( in_array($file, $active_plugins) ) continue;
		$need_to_active[] = $name;
	}

	foreach ($plugins['should_not_active'] as $file => $name) {
		if ( !in_array($file, $active_plugins) ) continue;
		$need_to_deactivate[] = $name;
	}

	if ( empty($need_to_active) && empty($need_to_deactivate) ) {
		new woo_for_b2b_Plugin();
		return;
	}

	add_action( 'admin_notices', function () use ($need_to_active, $need_to_deactivate) {
		$text = array();

		if ( !empty($need_to_active) ) {
			$text[] = 'activate ' . implode( ' and ', $need_to_active );
		}

		if ( !empty($need_to_deactivate) ) {
			$text[] = 'deactivate ' . implode( ' and ', $need_to_deactivate );
		}

		$text = implode( ' and ', $text );

		$message = __( "YANSIR B2B is not working because you need to {$text}", 'yansir-b2b' );

		echo '<div class="error"><p>' . $message . '</p></div>';
	} );
} );

// add_action( 'elementor/element/posts/section_query/before_section_end', function ( $element, $args ) {
// 	$post_types = array( '' => 'Default' ) + ElementorPro\Core\Utils::get_public_post_types( $post_type_args );

// 	$element->add_control( 'post_type_filter', [
// 		'type' => Elementor\Controls_Manager::SELECT,
// 		'label' => __( 'Post Type', 'yansir-b2b' ),
// 		'options' => $post_types
// 	] );
// }, 10, 2 );

// add_action( 'elementor/query/query_results', function ( $query, $widget ) {
// 	$settings = $widget->get_settings();
// 	$post_type = $settings['post_type_filter'];

// 	if ( empty($post_type) ) return;

// 	$vars = $query->query_vars;
// 	$vars['post_type'] = $post_type;
// 	$query->query($vars);
// }, 10, 2 );


//elementor汉化
add_filter( 'load_textdomain_mofile', function ( $mofile, $domain ) {
if ( $domain == 'elementor' || $domain == 'elementor-pro' ) {
    $mofile = __DIR__ . "/languages/" . pathinfo($mofile)['basename'];
}
return $mofile; }, 10, 2 );


//UAE汉化
add_filter( 'load_textdomain_mofile', function ( $mofile, $domain ) {
if ( $domain == 'uael' ) {
    $mofile = __DIR__ . "/languages/" . pathinfo($mofile)['basename'];
}
return $mofile; }, 10, 2 );

add_action( 'wp_footer', function () {
	if ( get_field('enable_minimize', 'option') ){
		echo "<style>
			.elementor-section {
				padding: clamp(5rem, calc(5rem + ((1vw - 0.36rem) * 6.4103)), 10rem) 0;
			}
			.elementor-section.custom-ele-section-css{
				padding: 0;
			}
			.elementor-inner-section {
				padding: 0;
			}
		</style>";
	};	

	if ( empty($_GET['elementor-preview']) ) return;

	// $normal_color = '#f44336';
	// $hover_color = '#df1a0c';

	// $selected_color = '#ff9800';
	// $selected_hover_color = '#e68a00';

	$normal_color = '#A4AFB6';
	$hover_color = '#8E9CA4';

	$selected_color = '#f44336';
	$selected_hover_color = '#df1a0c';

	echo "<style>
		.elementor-editor-section-settings {
			background: {$normal_color};
		}
		.elementor-editor-section-settings .elementor-editor-element-setting:first-child:before {
			border-right-color: {$normal_color};
		}
		.elementor-editor-section-settings .elementor-editor-element-setting:last-child:after {
			border-left-color: {$normal_color};
		}
		.elementor-section > .elementor-element-overlay:after {
			outline-color: {$normal_color};
		}

		.elementor-element-editable > div > .elementor-editor-section-settings {
			background: {$selected_color};
		}
		.elementor-element-editable > div > .elementor-editor-section-settings .elementor-editor-element-setting:first-child:before {
			border-right-color: {$selected_color};
		}
		.elementor-element-editable > div > .elementor-editor-section-settings .elementor-editor-element-setting:last-child:after {
			border-left-color: {$selected_color};
		}
		.elementor-section.elementor-element-editable > .elementor-element-overlay:after {
			outline-color: {$selected_color};
		}

		.elementor-editor-section-settings .elementor-editor-element-setting:hover {
			background: {$hover_color};
		}
		.elementor-editor-section-settings .elementor-editor-element-setting:first-child:hover:before {
			border-right-color: {$hover_color};
		}
		.elementor-editor-section-settings .elementor-editor-element-setting:last-child:hover:after {
			border-left-color: {$hover_color};
		}

		.elementor-element-editable > div > .elementor-editor-section-settings .elementor-editor-element-setting:hover {
			background: {$selected_hover_color};
		}
		.elementor-element-editable > div > .elementor-editor-section-settings .elementor-editor-element-setting:first-child:hover:before {
			border-right-color: {$selected_hover_color};
		}
		.elementor-element-editable > div > .elementor-editor-section-settings .elementor-editor-element-setting:last-child:hover:after {
			border-left-color: {$selected_hover_color};
		}

		.elementor-editor-column-settings .elementor-editor-element-setting:not(:hover) {
			background: {$normal_color};
		}
		.elementor-editor-column-settings .elementor-editor-element-setting:hover {
			background: {$hover_color};
		}
		.elementor-column > .elementor-element-overlay:after {
			outline-color: {$normal_color};
		}
		.elementor-column.elementor-dragging-on-child > .elementor-element-overlay {
			border: 1px solid {$normal_color};
		}

		.elementor-element-editable > div > .elementor-editor-column-settings .elementor-editor-element-setting:not(:hover) {
			background: {$selected_color};
		}
		.elementor-element-editable > div > .elementor-editor-column-settings .elementor-editor-element-setting:hover {
			background: {$selected_hover_color};
		}
		.elementor-column.elementor-element-editable > .elementor-element-overlay:after {
			outline-color: {$selected_color};
		}

		.elementor-sortable-placeholder:not(.elementor-column-placeholder) {
			background: {$normal_color};
		}
		.elementor-draggable-over:not([data-dragged-element=section]):not([data-dragged-is-inner=true]) > .elementor-empty-view>.elementor-first-add:after,
		.elementor-first-add.elementor-html5dnd-current-element:after {
			background: {$normal_color};
		}
		.elementor-first-add {
			border-color: {$normal_color};
		}

		.elementor-editor-widget-settings .elementor-editor-element-setting {
			background: {$hover_color};
		}
		.elementor-editor-widget-settings .elementor-editor-element-setting:not(:hover) {
			background: {$normal_color};
		}
		.elementor-edit-area-active .elementor-widget.elementor-element-edit-mode:hover {
			box-shadow: 0 0 0 1px {$normal_color};
		}

		.elementor-element-editable > div > .elementor-editor-widget-settings .elementor-editor-element-setting {
			background: {$selected_hover_color};
		}
		.elementor-element-editable > div > .elementor-editor-widget-settings .elementor-editor-element-setting:not(:hover) {
			background: {$selected_color};
		}
		.elementor-edit-area-active .elementor-widget.elementor-element-editable {
			box-shadow: 0 0 0 1px {$selected_color};
		}
		.elementor-edit-area-active .elementor-widget.elementor-element-editable:hover {
			box-shadow: 0 0 0 1px {$selected_hover_color};
		}
	</style>";
} );

add_action( 'admin_print_footer_scripts', function () {
	echo "<script>
		if (window.elementorCommon && elementorCommon.api) {
			let disable_class = false;

			elementorCommon.api.commands.on('run:after', (c, command, data) => {
				if (command == 'library/insert-template') disable_class = true;
				if (command == 'document/elements/import') disable_class = false;

				if (command != 'document/elements/create') return;
				if (!data.model || data.model.elType != 'section') return;
				if (disable_class) return;

				document.querySelector('[data-tab=advanced]').click();

				const css_classes = document.querySelector('[data-setting=css_classes]');
				css_classes.value = 'custom-ele-section-css';
				jQuery(css_classes).trigger('input');

				document.querySelector('[data-tab=layout]').click();
			});
		}
	</script>";
} );

include_once ( 'php/spacer-elementor.php' );